@@ -1,13 +1,14 @@
 import sys, os
-from pyautogui import typewrite
 import secrets
-
-
 def get_valid_int_selection(prompts, min, max, default=''):
     while True:
         if default!='':
-            typewrite(str(default))
-        s=input(prompts[0])
+            print(prompts[0]+',', 'Leave Blank For', default)
+        else:
+            print(prompts[0])
+        s=input()
+        if s=='' and default!='':
+            return default
         try:
             i=int(s)
             if(i in range(min, max)):
@@ -18,6 +19,7 @@ def get_valid_int_selection(prompts, min, max, default=''):
             print(prompts[2])
 
 def yes_no():
+    print("Save Settings?")
     a=input('y/n?')
     while True:
         if(a[0].lower()=='y'):
@@ -36,10 +38,12 @@ def menu_choice(name, options_list):
     return get_valid_int_selection(prompts, 1, len(options_list)+1)
     
 def get_string(prompt, default):
-    print(prompt)
-    typewrite(default)
+    print(prompt, 'Leave Blank for', default)
     server_adr = input()
-    return server_adr
+    if server_adr!='':
+        return server_adr
+    else:
+        return default
 
 def gen_key():
     print("Generating Key...")
@@ -71,8 +75,8 @@ def main():
     except ModuleNotFoundError:
         print('Running First Time Setup')
         key=gen_key()
-        server_adr=get_string("Enter VPN Server Address: ",'127.0.0.1')
-        prompts=['Enter VPN Port Address: ', 'Invalid Port', 'Invalid Port']
+        server_adr=get_string("Enter VPN Server Address,",'127.0.0.1')
+        prompts=['Enter VPN Port Address', 'Invalid Port', 'Invalid Port']
         server_port = get_valid_int_selection(prompts, 1024, 65535,'5000')
         save_key_svr_port('GinSettings.py', key, server_adr,server_port)
         return
@@ -84,10 +88,10 @@ def main():
         if i==1:
             key=gen_key()
         if i==2:
-            server_adr=get_string("Enter VPN Server Address: ",server_adr)
+            server_adr=get_string("Enter VPN Server Address,",server_adr)
         if i==3:
-            prompts=['Enter VPN Port Address: ', 'Invalid Port', 'Invalid Port']
-            server_port = get_valid_int_selection(prompts, 1024, 65535)
+            prompts=['Enter VPN Port Address', 'Invalid Port', 'Invalid Port']
+            server_port = get_valid_int_selection(prompts, 1024, 65535, server_port)
         if i==4:
             if yes_no():
                 save_key_svr_port('GinSettings.py', key, server_adr,server_port)
