@@ -72,7 +72,7 @@ def main():
         print("Config Not Found, run GinConfig")
         return
     global aes
-    aes=AES.AES(key,14)
+    aes=AES.AES(key)
     app = web.Application()
     app.router.add_route('POST', '/', recv_msg)
     loop = asyncio.get_event_loop()
